==> konversation_1.7.2.orig.tar.xz: konversation-1.7.2/src/viewer/chatwindow.h <==
/*
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
*/

/*
  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
*/

#ifndef CHATWINDOW_H
#define CHATWINDOW_H

#include "identity.h"
#include "common.h"

#include <QFile>
#include <QWidget>
#include <QVBoxLayout>


class IRCView;
class IRCInput;
class Server;

class ChatWindow : public QWidget
{
    Q_OBJECT

    public:
        explicit ChatWindow(QWidget* parent);
        ~ChatWindow();

        enum WindowType
        {
            Status=0,
            Channel,
            Query,
            DccChat,
            DccTransferPanel,
            RawLog,
            Notice,
            SNotice,
            ChannelList,
            Konsole,
            UrlCatcher,
            NicksOnline,
            LogFileReader
        };

        /** Clean up and close this tab.  Return false if you want to cancel the close. */
        virtual bool closeYourself(bool askForConfirmation = true);

        virtual void cycle();

        /** This should be called and set with a non-null server as soon
         *  as possibly after ChatWindow is created.
         *  @param newServer The server to set it to.
         */
        virtual void setServer(Server* newServer);
        /** This should be called if setServer is not called - e.g.
         *  in the case of konsolepanel.  This should be set as soon
         *  as possible after creation.
         */

        /** Get the server this is linked to.
         *  @return The server it is associated with, or null if none.
         */
        Server* getServer() const;
        void setTextView(IRCView* newView);
        IRCView* getTextView() const;
        void setInputBar(IRCInput* newInputBar) { m_inputBar = newInputBar; }
        IRCInput* getInputBar() { return m_inputBar; }
        virtual bool log();

        QString getName() const;
        QString getTitle() const;
        QString getURI(bool passNetwork = true);

        void setType(WindowType newType);
        WindowType getType() const;
        virtual bool isTopLevelView() const;

        virtual void sendText(const QString& /*text*/) {}

        virtual void append(const QString& nickname,const QString& message, const QHash<QString, QString> &messageTags, const QString& label = QString());
        virtual void appendRaw(const QString& message, bool self = false);
        virtual void appendLog(const QString& message);
        virtual void appendQuery(const QString& nickname,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(), bool inChannel = false);
        virtual void appendAction(const QString& nickname,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>());
        virtual void appendServerMessage(const QString& type,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(), bool parseURL = true);
        virtual void appendCommandMessage(const QString& command, const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(),
            bool parseURL = true, bool self = false);
        virtual void appendBacklogMessage(const QString& firstColumn,const QString& message);

        void clear();

        virtual QString getTextInLine();
        /** Reimplement this to return true in all classes that /can/ become front view.
         */
        virtual bool canBeFrontView();

        /** Reimplement this to return true in all classes that you can search in - i.e. use "Edit->Find Text" in.
         */
        virtual bool searchView();

        virtual bool notificationsEnabled() { return m_notificationsEnabled; }

        virtual bool eventFilter(QObject* watched, QEvent* e);

        QString logFileName() { return logfile.fileName(); }

        virtual void setChannelEncoding(const QString& /* encoding */) {}
        virtual QString getChannelEncoding() { return QString(); }
        virtual QString getChannelEncodingDefaultDesc() { return QString(); }
        bool isChannelEncodingSupported() const;

        /** Force updateInfo(info) to be emitted.
         *  Useful for when this tab has just gained focus
         */
        virtual void emitUpdateInfo();

        /** child classes have to override this and return true if they want the
         *  "insert character" item on the menu to be enabled.
         */
        virtual bool isInsertSupported() { return m_inputBar != 0; }

        /** child classes have to override this and return true if they want the
         *  "irc color" item on the menu to be enabled.
         */
        virtual bool areIRCColorsSupported() {return false; }

        Konversation::TabNotifyType currentTabNotification() const { return m_currentTabNotify; }
        QColor highlightColor();

        void msgHelper(const QString& recipient, const QString& message);

        void setMargin(int margin) { layout()->setMargin(margin); }
        void setSpacing(int spacing) { layout()->setSpacing(spacing); }

    Q_SIGNALS:
        void nameChanged(ChatWindow* view, const QString& newName);
        //void online(ChatWindow* myself, bool state);
        /** Emit this signal when you want to change the status bar text for this tab.
         *  It is ignored if this tab isn't focused.
         */
        void updateInfo(const QString &info);
        void updateTabNotification(ChatWindow* chatWin, const Konversation::TabNotifyType& type);

        void setStatusBarTempText(const QString&);
        void clearStatusBarTempText();

        void closing(ChatWindow* myself);

    public Q_SLOTS:
        void updateAppearance();

        void logText(const QString& text);

        /**
         * This is called when a chat window gains focus.
         * It enables and disables the appropriate menu items,
         * then calls childAdjustFocus.
         * You can call this manually to focus this tab.
         */
        void adjustFocus();

        virtual void appendInputText(const QString& text, bool fromCursor);
        virtual void indicateAway(bool away);


        virtual void setNotificationsEnabled(bool enable) { m_notificationsEnabled = enable; }
        void activateTabNotification(Konversation::TabNotifyType type);
        void resetTabNotification();

    protected Q_SLOTS:
        ///Used to disable functions when not connected
        virtual void serverOnline(bool online);

    protected:
        virtual void childEvent(QChildEvent* event);

        /** Some children may handle the name themselves, and not want this public.
         *  Increase the visibility in the subclass if you want outsiders to call this.
         *  The name is the string that is shown in the tab.
         *  @param newName The name to show in the tab
         */
        virtual void setName(const QString& newName);

        /** Called from adjustFocus */
        virtual void childAdjustFocus() = 0;

        void setLogfileName(const QString& name);
        void setChannelEncodingSupported(bool enabled);
        void cdIntoLogPath();

        int spacing();
        int margin();

        bool firstLog;
        QString name;
        QString logName;

        QFont font;

        IRCView* textView;
        /** A pointer to the server this chatwindow is part of.
         *  Not always non-null - e.g. for konsolepanel
         */

        IRCInput* m_inputBar;

        Server* m_server;
        QFile logfile;
        WindowType type;

        bool m_isTopLevelView;

        bool m_notificationsEnabled;

        bool m_channelEncodingSupported;

        Konversation::TabNotifyType m_currentTabNotify;

        bool m_recreationScheduled;
};
#endif

==> konversation-1.7.6.tar.xz: konversation-1.7.6/src/viewer/chatwindow.h <==
/*
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
*/

/*
  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
*/

#ifndef CHATWINDOW_H
#define CHATWINDOW_H

#include "identity.h"
#include "common.h"

#include <QFile>
#include <QWidget>
#include <QVBoxLayout>


class IRCView;
class IRCInput;
class Server;

class ChatWindow : public QWidget
{
    Q_OBJECT

    public:
        explicit ChatWindow(QWidget* parent);
        ~ChatWindow() override;

        enum WindowType
        {
            Status=0,
            Channel,
            Query,
            DccChat,
            DccTransferPanel,
            RawLog,
            Notice,
            SNotice,
            ChannelList,
            Konsole,
            UrlCatcher,
            NicksOnline,
            LogFileReader
        };

        /** Clean up and close this tab.  Return false if you want to cancel the close. */
        virtual bool closeYourself(bool askForConfirmation = true);

        virtual void cycle();

        /** This should be called and set with a non-null server as soon
         *  as possibly after ChatWindow is created.
         *  @param newServer The server to set it to.
         */
        virtual void setServer(Server* newServer);
        /** This should be called if setServer is not called - e.g.
         *  in the case of konsolepanel.  This should be set as soon
         *  as possible after creation.
         */

        /** Get the server this is linked to.
         *  @return The server it is associated with, or null if none.
         */
        Server* getServer() const;
        void setTextView(IRCView* newView);
        IRCView* getTextView() const;
        void setInputBar(IRCInput* newInputBar) { m_inputBar = newInputBar; }
        IRCInput* getInputBar() { return m_inputBar; }
        virtual bool log();

        QString getName() const;
        QString getTitle() const;
        QString getURI(bool passNetwork = true);

        void setType(WindowType newType);
        WindowType getType() const;
        virtual bool isTopLevelView() const;

        virtual void sendText(const QString& /*text*/) {}

        virtual void append(const QString& nickname,const QString& message, const QHash<QString, QString> &messageTags, const QString& label = QString());
        virtual void appendRaw(const QString& message, bool self = false);
        virtual void appendLog(const QString& message);
        virtual void appendQuery(const QString& nickname,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(), bool inChannel = false);
        virtual void appendAction(const QString& nickname,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>());
        virtual void appendServerMessage(const QString& type,const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(), bool parseURL = true);
        virtual void appendCommandMessage(const QString& command, const QString& message, const QHash<QString, QString> &messageTags = QHash<QString, QString>(),
            bool parseURL = true, bool self = false);
        virtual void appendBacklogMessage(const QString& firstColumn,const QString& message);

        void clear();

        virtual QString getTextInLine();
        /** Reimplement this to return true in all classes that /can/ become front view.
         */
        virtual bool canBeFrontView();

        /** Reimplement this to return true in all classes that you can search in - i.e. use "Edit->Find Text" in.
         */
        virtual bool searchView();

        virtual bool notificationsEnabled() { return m_notificationsEnabled; }

        bool eventFilter(QObject* watched, QEvent* e) override;

        QString logFileName() { return logfile.fileName(); }

        virtual void setChannelEncoding(const QString& /* encoding */) {}
        virtual QString getChannelEncoding() { return QString(); }
        virtual QString getChannelEncodingDefaultDesc() { return QString(); }
        bool isChannelEncodingSupported() const;

        /** Force updateInfo(info) to be emitted.
         *  Useful for when this tab has just gained focus
         */
        virtual void emitUpdateInfo();

        /** child classes have to override this and return true if they want the
         *  "insert character" item on the menu to be enabled.
         */
        virtual bool isInsertSupported() { return m_inputBar != 0; }

        /** child classes have to override this and return true if they want the
         *  "irc color" item on the menu to be enabled.
         */
        virtual bool areIRCColorsSupported() {return false; }

        Konversation::TabNotifyType currentTabNotification() const { return m_currentTabNotify; }
        QColor highlightColor();

        void msgHelper(const QString& recipient, const QString& message);

        void setMargin(int margin) { layout()->setMargin(margin); }
        void setSpacing(int spacing) { layout()->setSpacing(spacing); }

    Q_SIGNALS:
        void nameChanged(ChatWindow* view, const QString& newName);
        //void online(ChatWindow* myself, bool state);
        /** Emit this signal when you want to change the status bar text for this tab.
         *  It is ignored if this tab isn't focused.
         */
        void updateInfo(const QString &info);
        void updateTabNotification(ChatWindow* chatWin, const Konversation::TabNotifyType& type);

        void setStatusBarTempText(const QString&);
        void clearStatusBarTempText();

        void closing(ChatWindow* myself);

    public Q_SLOTS:
        void updateAppearance();

        void logText(const QString& text);

        /**
         * This is called when a chat window gains focus.
         * It enables and disables the appropriate menu items,
         * then calls childAdjustFocus.
         * You can call this manually to focus this tab.
         */
        void adjustFocus();

        virtual void appendInputText(const QString& text, bool fromCursor);
        virtual void indicateAway(bool away);


        virtual void setNotificationsEnabled(bool enable) { m_notificationsEnabled = enable; }
        void activateTabNotification(Konversation::TabNotifyType type);
        void resetTabNotification();

    protected Q_SLOTS:
        ///Used to disable functions when not connected
        virtual void serverOnline(bool online);

    protected:
        void childEvent(QChildEvent* event) override;

        /** Some children may handle the name themselves, and not want this public.
         *  Increase the visibility in the subclass if you want outsiders to call this.
         *  The name is the string that is shown in the tab.
         *  @param newName The name to show in the tab
         */
        virtual void setName(const QString& newName);

        /** Called from adjustFocus */
        virtual void childAdjustFocus() = 0;

        void setLogfileName(const QString& name);
        void setChannelEncodingSupported(bool enabled);
        void cdIntoLogPath();

        int spacing();
        int margin();

        bool firstLog;
        QString name;
        QString logName;

        QFont font;

        IRCView* textView;
        /** A pointer to the server this chatwindow is part of.
         *  Not always non-null - e.g. for konsolepanel
         */

        IRCInput* m_inputBar;

        Server* m_server;
        QFile logfile;
        WindowType type;

        bool m_isTopLevelView;

        bool m_notificationsEnabled;

        bool m_channelEncodingSupported;

        Konversation::TabNotifyType m_currentTabNotify;

        bool m_recreationScheduled;
};
#endif
